# coding: utf-8

# flake8: noqa
"""
    Data Space Catalog Service

    The service provides a REST API for managing and sharing catalog items.

    The version of the OpenAPI document: 0.2.0
    Contact: all-hiro@hiro-microdatacenters.nl
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ds_catalog.models.error_response import ErrorResponse
from ds_catalog.models.http_validation_error import HTTPValidationError
from ds_catalog.models.health_check import HealthCheck
from ds_catalog.models.validation_error import ValidationError
from ds_catalog.models.validation_error_loc_inner import ValidationErrorLocInner
