# coding: utf-8

# flake8: noqa

"""
    Data Space Catalog Service

    The service provides a REST API for managing and sharing catalog items.

    The version of the OpenAPI document: 0.2.0
    Contact: all-hiro@hiro-microdatacenters.nl
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from ds_catalog.api.catalog_api import CatalogApi
from ds_catalog.api.datasets_api import DatasetsApi
from ds_catalog.api.mmio_api import MMIOApi
from ds_catalog.api.sharing_api import SharingApi
from ds_catalog.api.default_api import DefaultApi

# import ApiClient
from ds_catalog.api_response import ApiResponse
from ds_catalog.api_client import ApiClient
from ds_catalog.configuration import Configuration
from ds_catalog.exceptions import OpenApiException
from ds_catalog.exceptions import ApiTypeError
from ds_catalog.exceptions import ApiValueError
from ds_catalog.exceptions import ApiKeyError
from ds_catalog.exceptions import ApiAttributeError
from ds_catalog.exceptions import ApiException

# import models into sdk package
from ds_catalog.models.error_response import ErrorResponse
from ds_catalog.models.http_validation_error import HTTPValidationError
from ds_catalog.models.health_check import HealthCheck
from ds_catalog.models.validation_error import ValidationError
from ds_catalog.models.validation_error_loc_inner import ValidationErrorLocInner
