# coding: utf-8

"""
    Data Space Catalog

    The service provides a REST API for managing and sharing catalog data. Interacts with connector services to obtain information about data products.

    The version of the OpenAPI document: 0.1.1
    Contact: all-hiro@hiro-microdatacenters.nl
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Ontology(str, Enum):
    """
    Ontology
    """

    """
    allowed enum values
    """
    DCAT_MINUS_3 = 'DCAT-3'
    DCAT_MINUS_AP = 'DCAT-AP'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Ontology from a JSON string"""
        return cls(json.loads(json_str))


